@@ -18,7 +18,13 @@
 #
 # You should have received a copy of the GNU General Public License
 
-__all__ = ["ControllerState", "OfflineSubstate", "EnabledSubstate", "ApplicationStatus"]
+__all__ = [
+    "ControllerState",
+    "OfflineSubstate",
+    "EnabledSubstate",
+    "ApplicationStatus",
+    "ErrorCode",
+]
 
 import enum
 
@@ -73,18 +79,36 @@ class EnabledSubstate(enum.IntEnum):
 class ApplicationStatus(enum.IntFlag):
     """Bit masks for the value reported in ``telemetry.application_status``.
 
-    These are constants, with the same names and values, in Moog code.
+    These are from https://github.com/lsst-ts/ts_rotator_controller/blob/main/include/actuatorTlm.h  # noqa
     """
 
-    HEX_FOLLOWING_ERROR_MASK = 0x00000001
-    HEX_MOVE_COMPLETE_MASK = 0x00000002
-    COMMAND_REJECT_MASK = 0x00000020
-    SAFETY_INTERLOCK = 0x00000040
-    EXTEND_LIMIT_SWITCH = 0x00000080
-    RETRACT_LIMIT_SWITCH = 0x00000100
-    ETHERCAT_PROBLEM = 0x00000200
-    DDS_COMMAND_SOURCE = 0x00000400
-    MOTION_TIMEOUT = 0x00000800
-    DRIVE_FAULT = 0x00002000
-    SIMULINK_FAULT = 0x00004000
-    ENCODER_FAULT = 0x00008000
+    EUI_CONNECTED = 0x4
+    COMMAND_REJECTED = 0x20
+    SAFETY_INTERLOCK = 0x40
+    EXTEND_LIMIT_SWITCH = 0x80
+    RETRACT_LIMIT_SWITCH = 0x100
+    ETHERCAT_PROBLEM = 0x200
+    DDS_COMMAND_SOURCE = 0x400
+    DDS_CONNECTED = 0x1000
+    DRIVE_FAULT = 0x2000
+    SIMULINK_FAULT = 0x4000
+    ENCODER_FAULT = 0x8000
+
+
+class ErrorCode(enum.IntEnum):
+    """Error codes.
+
+    The values are:
+
+    * CONTROLLER_FAULT: The low-level controller went to fault state.
+      Note that the CSC will trigger this if the camera cable wrap is not
+      following closely enough, or if a user issues the ``fault`` command.
+    * CONNECTION_LOST: The CSC lost communication with the low-level
+      controller.
+    * NO_CONFIG: The CSC did not receive configuration from the low-level
+      controller shortly after connecting to it.
+    """
+
+    CONTROLLER_FAULT = 1
+    CONNECTION_LOST = 2
+    NO_CONFIG = 3
